ToDo (24-July-2020)
===================

Functionality
-------------
* Finalize implementation of L1B, L1C products (module lv1_io.py)
* Add scripts to obtain reasonable Level-1 product sizes

Check Level-1 products on completeness
--------------------------------------
* Verify consistency between the dset_stored and the dimension lengths

Check Level-1 products on consistency
-------------------------------------
1. Add documentation on timestamps to IODS, including
   * global attribute 'reference_day',
   * tolerance of period covered by the various timestamp datasets
2. Summarize meaning of timestamps in the products in the lv1_io.py module
3. Verify consistency of filename, global attributes and various timestamps


